@@ -34,10 +34,10 @@ class Baidu(CheckIn):
                 error_count += 1
         msg = [
             {"name": "站点地址", "value": site},
-            {"name": "剩余可推送 url 条数", "value": remian},
-            {"name": "成功推送的 url 条数", "value": success_count},
-            {"name": "成功推送的 url 次数", "value": times - error_count},
-            {"name": "失败推送的 url 次数", "value": error_count},
+            {"name": "剩余条数", "value": remian},
+            {"name": "成功条数", "value": success_count},
+            {"name": "成功次数", "value": times - error_count},
+            {"name": "失败次数", "value": error_count},
         ]
         return msg
 
