@@ -243,6 +243,12 @@ class DuoKan(CheckIn):
         msg = {"name": "每日签到", "value": result.get("msg")}
         return msg
 
+    def delay(self, cookies, date):
+        url = "https://www.duokan.com/store/v0/award/coin/delay"
+        data = f"date={date}&{self.get_data(cookies=cookies)}&withid=1"
+        ret = requests.post(url=url, data=data, cookies=cookies, headers=self.headers).json()
+        return ret
+
     def info(self, cookies):
         url = "https://www.duokan.com/store/v0/award/coin/list"
         data = f"sandbox=0&{self.get_data(cookies=cookies)}&withid=1"
@@ -252,10 +258,14 @@ class DuoKan(CheckIn):
         if "尚未登录" not in result.get("msg"):
             coin = sum([one.get("coin") for one in result.get("data", {}).get("award")])
             msg.append({"name": "当前书豆", "value": coin})
-            msg += [
-                {"name": f"{one.get('expire')} 到期", "value": f"{one.get('coin')} 书豆"}
-                for one in result.get("data", {}).get("award")
-            ]
+            for one in result.get("data", {}).get("award"):
+                if one.get("delay") == 1:
+                    ret = self.delay(cookies, one.get("expire"))
+                    msg.append(
+                        {"name": f"{one.get('expire')} 到期", "value": f"{one.get('coin')} 书豆 | 延期：{ret.get('msg')}"}
+                    )
+                else:
+                    msg.append({"name": f"{one.get('expire')} 到期", "value": f"{one.get('coin')} 书豆"})
             return msg
         else:
             return [{"name": "账号异常", "value": "Cookie 失效"}]
@@ -294,7 +304,7 @@ class DuoKan(CheckIn):
                     num += 30
                     print("体验任务完成啦！豆子 +30")
                 else:
-                    print(result.get("data"))
+                    continue
             msg = {"name": "体验任务", "value": f"获得 {num} 豆子"}
         else:
             msg = {"name": "体验任务", "value": f"{response.text}"}
@@ -327,20 +337,26 @@ class DuoKan(CheckIn):
     def download(self, cookies):
         url = "https://www.duokan.com/events/common_task_gift"
         data = f"code=J18UK6YYAY&chances=17&{self.get_data(cookies=cookies)}&withid=1"
-        response = requests.post(url=url, data=data, cookies=cookies, headers=self.headers)
-        result = response.json()
-        msg = {"name": "下载任务", "value": result.get("msg")}
+        count = 0
+        while True:
+            response = requests.post(url=url, data=data, cookies=cookies, headers=self.headers)
+            result = response.json()
+            if result.get("result") == 130014:
+                break
+            count += 1
+        msg = {"name": "下载任务", "value": f"完成 {count} 次"}
         return msg
 
     def task(self, cookies):
         success_count = 0
         url = "https://www.duokan.com/events/tasks_gift"
-        for code in self.code_list:
-            data = f"code={code}&chances=3&{self.get_data(cookies=cookies)}&withid=1"
-            response = requests.post(url=url, data=data, cookies=cookies, headers=self.headers)
-            result = response.json()
-            if result.get("result") == 0:
-                success_count += 1
+        for i in range(3):
+            for code in self.code_list:
+                data = f"code={code}&chances=3&{self.get_data(cookies=cookies)}&withid=1"
+                response = requests.post(url=url, data=data, cookies=cookies, headers=self.headers)
+                result = response.json()
+                if result.get("result") == 0:
+                    success_count += 1
         msg = {"name": "其他任务", "value": f"完成 {success_count} 个"}
         return msg
 
