@@ -115,7 +115,7 @@ class VQQ(CheckIn):
         sign_twice_msg = self.sign_twice(headers=headers, cookies=cookie)
         task_msg = self.tasks(headers=headers, cookies=cookie)
         msg = [
-                  {"name": "用户信息", "value": nick},
+                  {"name": "账号信息", "value": nick},
                   {"name": "签到奖励1", "value": sign_once_msg},
                   {"name": "签到奖励2", "value": sign_twice_msg},
               ] + task_msg
